@@ -12,7 +12,6 @@ from django.template.library import InvalidTemplateLibrary, import_library
 
 from dotenv import load_dotenv
 
-from coltrane.config.paths import get_output_directory
 from coltrane.config.settings import DEFAULT_COLTRANE_SETTINGS
 
 from .utils import dict_merge
@@ -41,6 +40,7 @@ DEFAULT_MIDDLEWARE_SETTINGS = [
 DEFAULT_INSTALLED_APPS = [
     "django.contrib.humanize",
     "django.contrib.staticfiles",
+    "django_fastdev",
     "coltrane",
 ]
 
@@ -103,6 +103,7 @@ def _get_default_template_settings(base_dir: Path):
     builtins = [
         "django.contrib.humanize.templatetags.humanize",
         "django.templatetags.static",
+        "coltrane.templatetags.coltrane_tags",
     ]
     builtins.extend(template_tags)
 
@@ -116,6 +117,7 @@ def _get_default_template_settings(base_dir: Path):
                 "context_processors": [
                     "django.template.context_processors.request",
                     "django.template.context_processors.debug",
+                    "django.template.context_processors.static",
                 ],
             },
         }
@@ -186,7 +188,7 @@ def _merge_settings(base_dir: Path, django_settings: Dict[str, Any]) -> Dict[str
 
     if is_whitenoise_installed:
         middleware.insert(1, "whitenoise.middleware.WhiteNoiseMiddleware")
-        installed_apps.insert(len(installed_apps) - 1, "whitenoise.runserver_nostatic")
+        installed_apps.insert(0, "whitenoise.runserver_nostatic")
 
     if debug and not is_build_management_command:
         # Add settings required for django-browser-reload when appropriate
@@ -225,6 +227,9 @@ def _merge_settings(base_dir: Path, django_settings: Dict[str, Any]) -> Dict[str
             },
         },
         "COLTRANE": DEFAULT_COLTRANE_SETTINGS,
+        # Hard-coding `SETTINGS_MODULE` even though it kind of doesn't make sense, but
+        # is needed for rendering a nice 500 page on local when debugging
+        "SETTINGS_MODULE": "coltrane",
     }
 
     if is_whitenoise_installed:
